package de.jrpie.android.search

import android.app.SearchManager
import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.util.Log
import androidx.appcompat.app.AppCompatActivity

class SearchActivity : AppCompatActivity() {
    private val defaultEngine = "https://duckduckgo.com/?q=%s"

    // prefix -> URL format string
    private val engines = mapOf(
        Pair("ddg", defaultEngine),
        Pair("sp", "https://www.startpage.com/sp/search?query=%s"),
        Pair("g", "https://google.com/search?q=%s"),
        Pair("wp", "https://en.wikipedia.org/w/index.php?search=%s"),
        Pair("aw", "https://wiki.archlinux.org/index.php?search=%s&title=Special%3ASearch&go=Go"),
        Pair("imslp", "https://www.google.com/search?q=site:imslp.org+%s"),
        Pair("zbm", "https://zbmath.org/?q=%s"),
        Pair("msn", "https://mathscinet.ams.org/mathscinet/publications-search?query=%s")
    )

    private fun search(engine: String, query: String) {
        val intent = Intent(Intent.ACTION_VIEW)
        intent.setData(
            Uri.parse(
                String.format(
                    engine, query
                )
            )
        )
        startActivity(intent)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        if (intent.action != Intent.ACTION_WEB_SEARCH) {
            finish()
        }

        val query = intent.getCharSequenceExtra(SearchManager.QUERY).toString()

        val prefix = query.split(" ")[0].lowercase()
        Log.i("µSearch", "prefix=\"$prefix\"")
        engines[prefix]?.let {
            search(it, query.replace("^${prefix} ".toRegex(), ""))
            return
        }
        search(defaultEngine, query)
    }
}
